@@ -23,29 +23,29 @@ class Authenticate:
         })
         return self.session
 
-    def apikey_header(self):
-        self.session.headers.update({
-            self.security['name']: self.asset[self.security['name']]
-        })
-        return self.session
-
-    def apikey_cookie(self):
-        self.session.cookies.update({
-            self.security['name']: self.asset[self.security['name']]
-        })
-        return self.session
-
-    def apikey_query(self):
-        self.params.update({
-            self.security['name']: self.asset[self.security['name']]
-        })
+    def apikey(self):
+        if self.security['in'] == 'header':
+            self.session.headers.update({
+                self.security['name']: self.asset[self.security['name']]
+            })
+        elif self.security['in'] == 'cookie':
+            self.session.cookies.update({
+                self.security['name']: self.asset[self.security['name']]
+            })
+        elif self.security['in'] == 'query':
+            self.params.update({
+                self.security['name']: self.asset[self.security['name']]
+            })
         return self.session
 
     def oauth2_client_credentials(self):
+        scopes = self.asset.get('scopes')
+        if scopes:
+            scopes = scopes.join(' ')
         data = {
             'client_id': self.asset['client_id'],
             'client_secret': self.asset['client_secret'],
-            'scope': self.asset.get('scopes', []).join(' '),
+            'scope': scopes,
             'grant_type': 'client_credentials'
         }
 
