@@ -29,7 +29,7 @@ class Runner(Authenticate):
             self.asset_url_key = self.asset_manifest.get('meta', {}).get('asset_url_key', 'url')
 
         # Build session
-        self.session = Session()
+        self.session = WrappedSession()
         http_proxy = os.getenv('http_proxy') or self.asset.get('http_proxy')
         self.session.proxies = {
             'http_proxy': http_proxy,
@@ -47,19 +47,14 @@ class Runner(Authenticate):
         )
 
     def _get_asset_name(self):
-        _in = self.security.get('in')
-        if {'username', 'password'} <= set(self.inputs):
+        if {'username', 'password'} <= set(self.asset):
             return 'http_basic'
-        elif {'token'} <= set(self.inputs):
+        elif {'token'} <= set(self.asset):
             return 'http_bearer'
-        elif {'clientSecret', 'clientId', 'tokenUrl', 'scope'} <= set(self.inputs):
+        elif {'client_secret', 'client_id', 'token_url'} <= set(self.asset):
             return 'oauth2_client_credentials'
-        elif _in == 'header':
-            return 'apikey_header'
-        elif _in == 'query':
-            return 'apikey_query'
-        elif _in == 'cookie':
-            return 'apikey_cookie'
+        else:
+            return 'apikey'
 
     def _load_schemas(self):
 
@@ -146,3 +141,16 @@ class Runner(Authenticate):
         )
         resp = self.parse_response(response)
         return resp
+
+
+class WrappedSession(Session):
+    """A wrapper for requests.Session to override 'verify' property, ignoring REQUESTS_CA_BUNDLE environment variable.
+    This is a workaround for https://github.com/kennethreitz/requests/issues/3829 (will be fixed in requests 3.0.0)
+    Code sourced from user intgr https://github.com/kennethreitz/requests/issues/3829
+    """
+
+    def merge_environment_settings(self, url, proxies, stream, verify, *args, **kwargs):
+        if self.verify is False:
+            verify = False
+
+        return super(WrappedSession, self).merge_environment_settings(url, proxies, stream, verify, *args, **kwargs)
\ No newline at end of file
